/*
 * HandlerApp.cpp
 *
 * Copyright 1997-1998 Geoffrey Clements
 *
 * License:
 * 		This code may be freely used in your programs.
 */

#ifndef _DATAHANDLER_H_
#include "DataHandler.h"
#endif

class HandlerWindow : public BWindow {
public:
	HandlerWindow (BRect area, const char *title, window_type kind, uint32 flags);
	bool QuitRequested ();
};

HandlerWindow::HandlerWindow(BRect area, const char *title, window_type kind, uint32 flags) :
	BWindow(area, title, kind, flags) {
}


bool HandlerWindow::QuitRequested () {
	BMessage msg;
	
	GetConfigMessage (&msg);
	BPath prefsPath;
	status_t err = find_directory (B_USER_SETTINGS_DIRECTORY, &prefsPath);
	
	if (err == B_OK) {
		err = prefsPath.Append ("TIFF EBitmap Handler.prefs", true);
		if (err == B_OK) {
			BFile prefsFile (prefsPath.Path (), O_RDWR | O_CREAT);
			err = prefsFile.InitCheck ();
			if (err == B_OK) {
				err = msg.Flatten (&prefsFile);
			}
		}
	}
	// save settings here
	be_app->PostMessage(B_QUIT_REQUESTED);
	return true;	/*	we will die!		*/
}

void main () {
	BApplication app("application/x-vnd.GPC-TIFF_Handler");
	HandlerWindow *window = new HandlerWindow(BRect(100,100,400,300), 
		"TIFF Settings", B_TITLED_WINDOW, B_NOT_RESIZABLE | B_NOT_ZOOMABLE);
	BView *config = NULL;
	BRect extent(0,0,300,200);
	BMessage settingsMsg;
	
	// read settings here and fill in settingsMsg
	BPath prefsPath;
	status_t err = find_directory (B_USER_SETTINGS_DIRECTORY, &prefsPath);
	
	if (err == B_OK) {
		err = prefsPath.Append ("handler.prefs", true);
		if (err == B_OK) {
			BFile prefsFile (prefsPath.Path (), O_RDONLY);
			err = prefsFile.InitCheck ();
			if (err == B_OK) {
				settingsMsg.MakeEmpty ();
				err = settingsMsg.Unflatten (&prefsFile);
			}
		}
	}

	if (err == B_OK) {
		err = MakeConfig(&settingsMsg, config, extent);
	}
	else {
		err = MakeConfig(NULL, config, extent);
	}
	if ((err < B_OK) || (config == NULL)){
		BAlert *alrt = new BAlert("No Config", "TIFF EBitmap Handler: Oopps, something went wrong.", "Quit");
		alrt->Go();
		exit(1);
	}
	window->ResizeTo(extent.Width(), extent.Height());
	window->AddChild(config);
	window->Show();
	app.Run();
}
