/*
 * ebitmap_lib.cpp
 *
 * Copyright 1997-1998 Geoffrey Clements
 *
 * License:
 * 		This code may be freely used in your programs.
 */

#ifndef EBITMAP_H
#include "EBitmap.h"
#endif
#ifndef EBITMAP_LIB_H
#include "ebitmap_lib.h"
#endif

BMessage *bbitmap_to_ebitmap (BBitmap *bm) {
	BMessage *msg = NULL;
	
	if (bm != NULL) {
		msg = new BMessage (E_BITMAP);
		msg->MakeEmpty ();
		msg->AddString ("class", "EBitmap");
		msg->AddString ("class", "BArchivable");
		BRect imageBounds = bm->Bounds ();
		msg->AddInt32 ("storage", E_STORAGE_SELF);
		msg->AddInt32 ("width", imageBounds.IntegerWidth ()+1);
		msg->AddInt32 ("height", imageBounds.IntegerHeight ()+1);
		msg->AddInt32 ("photometric", bm->ColorSpace ());
		msg->AddInt32 ("row bytes", bm->BytesPerRow ());
		msg->AddData ("bits", B_RAW_TYPE, bm->Bits (), bm->BitsLength ());
	}

	return msg;	
}

BBitmap *ebitmap_to_bbitmap (BMessage *msg) {
	BBitmap *bm = NULL;
	
	if ((msg != NULL) && (msg->what == E_BITMAP)) {
		int32 width, height, photometric, storage, rowBytes, bytesRead;
		if (msg->FindInt32 ("width", &width) == B_OK) { // required
			if (msg->FindInt32 ("height", &height) == B_OK) { // required
				if ((msg->FindInt32 ("photometric", &photometric) == B_OK) &&
					((photometric == B_RGB_32_BIT) || (photometric == B_COLOR_8_BIT))) { // required
					if ((msg->FindInt32 ("storage", &storage) == B_OK) && (storage == E_STORAGE_SELF)) { // required
						if (msg->FindInt32 ("row bytes", &rowBytes) != B_OK) { // probably a good idea
							rowBytes = width*sizeof (rgb_color);
						}
						bm = new BBitmap (BRect (0, 0, width-1, height-1), static_cast<color_space>(photometric));
						if (bm->IsValid ()) {
							// fill in the rest of the BBitmap here
							char *buf = static_cast<char *>(bm->Bits ());
							if (buf != NULL) {
								char *data;
								// SetBits() is kind of screwy so we just use Bits() and memcpy()
								if (msg->FindData ("bits", B_RAW_TYPE, 0, &data, &bytesRead) == B_OK) {
									memcpy (buf, data, rowBytes*height);
								}
							}
						}
						else {
							delete bm;
							bm = NULL;
						}
					}
				}
			}
		}
	}
	return bm;
}
